==> color-sorter-1.0.0.tgz: package/color-sorter.js <==
const tinycolor = require('tinycolor2')

/**
 * Sort by saturation, high to low (ASC, 100%  - 0%)
 * @param {*} colorA An {hsl: {}}-like object
 * @param {*} colorB An {hsl: {}}-like object
 */
function sortBySaturation(colorA, colorB) {
	return colorA.saturation - colorB.saturation
}

/**
 * Sort by hue, red-yellow-green-blue-purple (0-360)
 * @param {*} colorA An {hsl: {}}-like object
 * @param {*} colorB An {hsl: {}}-like object
 */
function sortByHue({hsl: colorA}, {hsl: colorB}) {
	const {hue: hueA} = colorA
	const {hue: hueB} = colorB

	// If the hues are the same, sort by saturation
	if (hueA === hueB) {
		return sortBySaturation(colorA, colorB)
	}

	return hueA - hueB
}

/**
 * Sort by alpha channel, transparent to opaque
 * @param {*} colorA An {hsl: {}}-like object
 * @param {*} colorB An {hsl: {}}-like object
 */
function sortByAlpha({hsl: colorA}, {hsl: colorB}) {
	if (colorA.alpha === colorB.alpha) {
		return sortByLightness(colorA, colorB)
	}

	return colorB.alpha - colorA.alpha
}

/**
 * Sort by lightness, light to dark
 * @param {*} colorA An {hsl: {}}-like object
 * @param {*} colorB {hsl: {}}-like object
 */
function sortByLightness(colorA, colorB) {
	const {lightness: lightnessA} = colorA
	const {lightness: lightnessB} = colorB

	return lightnessB - lightnessA
}

/**
 * Determines if a given color is a pure grey
 * @param {*} color An {hsl: {}}-like object
 */
function isGrey(color) {
	return color.hsl.saturation === 0
}

/**
 * Sort an array of color objects
 *
 * @param colors An array of {value: #f00;}-like objects
 * @returns array A new sorted array
 */
module.exports = colors => {
	// add an `hsl` prop to our array to use for sorting
	const mapped = colors.map(color => {
		const {h: hue, s: saturation, l: lightness, a: alpha} = tinycolor(
			color.value
		).toHsl()

		return {
			...color,
			hsl: {hue, saturation, lightness, alpha}
		}
	})

	return (
		mapped
			// sort by hue
			.sort(sortByHue)
			// remove the grey colors
			.filter(color => !isGrey(color))
			// and append the grey colors to the back
			// and sort the greys by lightness
			.concat(mapped.filter(color => isGrey(color)).sort(sortByAlpha))
			// and finally strip the `hsl` prop from our output array
			.map(color => {
				const {hsl, ...originalColor} = color
				return originalColor
			})
	)
}

==> color-sorter-2.0.0.tgz: package/color-sorter.js <==
const tinycolor = require('tinycolor2')

/*
 * Sort by saturation, high to low (ASC, 100%  - 0%)
 */
function sortBySaturation(colorA, colorB) {
	return colorA.saturation - colorB.saturation
}

/*
 * Sort by hue, red-yellow-green-blue-purple (0-360)
 */
function sortByHue({hsl: colorA}, {hsl: colorB}) {
	const {hue: hueA} = colorA
	const {hue: hueB} = colorB

	// If the hues are the same, sort by saturation
	if (hueA === hueB) {
		return sortBySaturation(colorA, colorB)
	}

	return hueA - hueB
}

/*
 * Sort by alpha channel, transparent to opaque
 */
function sortByAlpha({hsl: colorA}, {hsl: colorB}) {
	if (colorA.alpha === colorB.alpha) {
		return sortByLightness(colorA, colorB)
	}

	return colorB.alpha - colorA.alpha
}

/*
 * Sort by lightness, light to dark
 */
function sortByLightness(colorA, colorB) {
	const {lightness: lightnessA} = colorA
	const {lightness: lightnessB} = colorB

	return lightnessB - lightnessA
}

/*
 * Determines if a given color is a pure grey
 */
function isGrey(color) {
	return color.hsl.saturation === 0
}

/*
 * Sort an array of CSS colors
 *
 * @param colors An array of CSS colors
 * @returns array A new sorted array
 */
module.exports = colors => {
	// Add an `hsl` prop to our array to use for sorting
	const mapped = colors.map(color => {
		const {h: hue, s: saturation, l: lightness, a: alpha} = tinycolor(
			color
		).toHsl()

		return {
			authored: color,
			hsl: {hue, saturation, lightness, alpha}
		}
	})

	return (
		mapped
			// Sort by hue
			.sort(sortByHue)
			// Remove the grey colors
			.filter(color => !isGrey(color))
			.concat(
				// Shift the grey colors to the back
				mapped
					.filter(color => isGrey(color))
					// And sort the greys by lightness
					.sort(sortByAlpha)
			)
			// Finally, return the array in the form it was given to us
			.map(color => color.authored)
	)
}
